package Daje::Workflow::Errors::Error;
use Mojo::Base -base, -signatures;

# Daje::Workflow::Errors::Error - Storage container for workflow errors
#
# METHODS
# =======
#
#   $error->has_error();
#
#   $error->add_error("Error");
#
#

has 'error' => " ";
has 'has_error' => 0;

sub add_error($self, $error) {
    return unless length($error);

    my $err = $self->error();
    $err = $error . '\n' . $err;
    $self->error($error);
    $self->has_error(1);
}

1;











#################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################

=head1 NAME

Daje::Workflow::Errors::Error


=head1 DESCRIPTION

Daje::Workflow::Errors::Error - Storage container for workflow errors



=head1 REQUIRES

L<Mojo::Base> 


=head1 METHODS


  $error->has_error();

  $error->add_error("Error");




=cut

