package Daje::Workflow::Common::Checks::Base;
use Mojo::Base -base, -signatures;
use v5.42;

# NAME
#
# Daje::Workflow::Common::Checks::Base - Baseclass for workflow check classes
#
#
# DESCRIPTION
# ===========
#
# REQUIRES
#
# Mojo::Base>
#
#
# METHODS
# =======
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
# janeskil1525 E<lt>janeskil1525@gmail.comE<gt>
#

has 'context';
has 'checks';
has 'error';
has 'model';

1;









#################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################

=head1 NAME

Daje::Workflow::Common::Checks::Base


=head1 DESCRIPTION

NAME

Daje::Workflow::Common::Checks::Base - Baseclass for workflow check classes



REQUIRES

Mojo::Base>




=head1 REQUIRES

L<v5.40> 

L<Mojo::Base> 


=head1 METHODS




=head1 AUTHOR

janeskil1525 E<lt>janeskil1525@gmail.comE<gt>



=head1 LICENSE


Copyright (C) janeskil1525.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.



=cut

