package Daje::Workflow::Create::State;
use Mojo::Base -base, -signatures;

our $VERSION = "0.01";


sub create($self) {

}
1;













#################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################

=head1 NAME

Daje::Workflow::Create::State


=head1 DESCRIPTION

pod generated by Pod::Autopod - keep this line to make pod updates possible ####################


=head1 REQUIRES

L<Mojo::Base> 


=head1 METHODS

=head2 create($self)

 create($self)();


=cut

