use strict;
use Test::More 0.98;

use_ok $_ for qw(
    Daje::Workflow
    Daje::Workflow::Activities::Files::Save
    Daje::Workflow::Activities::Document::Builder
    Daje::Workflow::Activities::Save
);

done_testing;

